@@ -35,6 +35,9 @@ FAILEDOPERATION_INVALIDMPSUSER = 'FailedOperation.InvalidMpsUser'
 # 操作失败：无效用户。
 FAILEDOPERATION_INVALIDUSER = 'FailedOperation.InvalidUser'
 
+# 操作失败：网络错误。
+FAILEDOPERATION_NETWORKERROR = 'FailedOperation.NetWorkError'
+
 # 操作失败：设置源通知错误。
 FAILEDOPERATION_SETSOURCENOTIFY = 'FailedOperation.SetSourceNotify'
 
@@ -203,6 +206,9 @@ INVALIDPARAMETERVALUE_DISABLEHIGHERVIDEOBITRATE = 'InvalidParameterValue.Disable
 # 无效的禁止分辨率低转高开关值。
 INVALIDPARAMETERVALUE_DISABLEHIGHERVIDEORESOLUTION = 'InvalidParameterValue.DisableHigherVideoResolution'
 
+# 水印文本重复
+INVALIDPARAMETERVALUE_DUPLICATEDTEXTCONTENT = 'InvalidParameterValue.DuplicatedTextContent'
+
 # 模板开启的检测项为空。
 INVALIDPARAMETERVALUE_EMPTYDETECTITEM = 'InvalidParameterValue.EmptyDetectItem'
 
@@ -341,6 +347,9 @@ INVALIDPARAMETERVALUE_SAMPLERATE = 'InvalidParameterValue.SampleRate'
 # 参数值错误：SampleType。
 INVALIDPARAMETERVALUE_SAMPLETYPE = 'InvalidParameterValue.SampleType'
 
+# Service参数值错误
+INVALIDPARAMETERVALUE_SERVICE = 'InvalidParameterValue.Service'
+
 # SessionContext 过长。
 INVALIDPARAMETERVALUE_SESSIONCONTEXTTOOLONG = 'InvalidParameterValue.SessionContextTooLong'
 
@@ -356,6 +365,9 @@ INVALIDPARAMETERVALUE_SOUNDSYSTEM = 'InvalidParameterValue.SoundSystem'
 # SourceLanguage参数错误
 INVALIDPARAMETERVALUE_SOURCELANGUAGE = 'InvalidParameterValue.SourceLanguage'
 
+# SourceText参数错误
+INVALIDPARAMETERVALUE_SOURCETEXT = 'InvalidParameterValue.SourceText'
+
 # 源文件错误。
 INVALIDPARAMETERVALUE_SRCFILE = 'InvalidParameterValue.SrcFile'
 
@@ -398,6 +410,9 @@ INVALIDPARAMETERVALUE_TASKID = 'InvalidParameterValue.TaskId'
 # 参数错误：文字透明度。
 INVALIDPARAMETERVALUE_TEXTALPHA = 'InvalidParameterValue.TextAlpha'
 
+# TextContent参数值错误
+INVALIDPARAMETERVALUE_TEXTCONTENT = 'InvalidParameterValue.TextContent'
+
 # 参数错误：文字模板。
 INVALIDPARAMETERVALUE_TEXTTEMPLATE = 'InvalidParameterValue.TextTemplate'
 
@@ -470,8 +485,14 @@ RESOURCENOTFOUND_PERSON = 'ResourceNotFound.Person'
 # 资源不存在：模板不存在。
 RESOURCENOTFOUND_TEMPLATENOTEXIST = 'ResourceNotFound.TemplateNotExist'
 
+# 用户未注册。
+RESOURCENOTFOUND_USERUNREGISTER = 'ResourceNotFound.UserUnregister'
+
 # 资源不存在：关键词。
 RESOURCENOTFOUND_WORD = 'ResourceNotFound.Word'
 
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
+# 单次请求text超过长度限制
+UNSUPPORTEDOPERATION_TEXTTOOLONG = 'UnsupportedOperation.TextTooLong'
